# Библиография
## Общие замечания
* Данный шаблон рассчитан на поддержку работы двух реализаций автоматизированного формирования списка литературы и управления библиографией:
  * встроенная реализация с загрузкой файла через движок ```bibtex``` при поддержке шаблонов пакета [```gost```](http://mirrors.ctan.org/biblio/bibtex/contrib/gost/gost.pdf);
  * реализация пакетом ```biblatex``` через движок ```biber``` (рекомендуемая) при поддержке шаблонов пакета [```biblatex-gost```](http://mirrors.ctan.org/macros/latex/contrib/biblatex-contrib/biblatex-gost/doc/biblatex-gost.pdf).
* Лучше всего всегда обрамлять значение BibTeX-атрибутов в фигурные скобки или кавычки (то есть вместо *month = jul* писать *month = {jul}*).
* Также лучше всегда указывать язык BibTeX-записи (например, *language = {russian}* или *language = {english}*). Запись языков всегда должна вестись строчными (маленькими) буквами.
* Для оптимального оформления списка литературы стоит убедиться, что исходный *.bib файл заполнен правильным образом.
Примеры заполнения записей и результаты применения к ним основных стилей приведены в [описании стилей пакета ```gost```](http://ctan.org/tex-archive/biblio/bibtex/contrib/gost) и в [примерах применения пакета ```biblatex-gost```](http://mirrors.ctan.org/macros/latex/contrib/biblatex-contrib/biblatex-gost/doc/biblatex-gost-examples.pdf).


## Назначение и размещение файлов с библиографией
Файлы с библиографией расположены в папке [biblio/](./biblio/):
* работы автора в ваковских журналах — [authorpapersVAK.bib](./biblio/authorpapersVAK.bib);
* работы автора в неваковских журналах — [authorpapers.bib](./biblio/authorpapers.bib);
* работы автора тезисы на конференциях — [authorconferences.bib](./biblio/authorconferences.bib);
* чужие работы, на которые автор ссылается — [othercites.bib](./biblio/othercites.bib).

## Замечания по реализациям библиографии
### ```biblatex``` + ```biblatex-gost``` + biber
* В версии ```biblatex``` 3.1 существует [баг](https://github.com/plk/biblatex/issues/355), поэтому лучше использовать версии 3.0 или 3.2.
* Предупреждение в логе
```
Package biblatex Warning: 'babel/polyglossia' detected but 'csquotes' missing.
(biblatex) Loading 'csquotes' recommended.
```
является рекомендацией автора ```biblatex``` и ```csquotes```.
```\usepackage{csquotes}``` уберёт этот warning-recommendation, только смысла в этом пакете для русскоязычной диссертации нет — он для западноевропейских языков. Для русского языка ```babel``` и ```polyglossia``` (с параметром ```babelshorthands```) что могут — то решают.
* Посредством этой связки решается вопрос [подсчета авторских литературных источников](https://github.com/AndreyAkinshin/Russian-Phd-LaTeX-Dissertation-Template/issues/33#issuecomment-150912772).

### Встроенная + ```gost``` + bibtex
* В bibtex отсутствует встроенная возможность создавать несколько списков литературы для одного документа, поэтому для автореферата придётся обходиться без ссылок на работы других авторов, оставляя нужный по ГОСТ список работ автора по теме диссертации.
* Отечественный ГОСТ очень суров, в настоящее время ещё не создали такой BibTeX-стиль, который бы ему полностью соответствовал. В данном шаблоне используется стиль *utf8gost71u.bst*, он более или менее вменяемый и достаточно близок к стандарту. Впрочем, при написании диссертации редко кто требует точного соответствия ГОСТ-у, лишь всё было оформлено красиво и однообразно. Если utf8gost71u.bst вас не устраивает, то вы можете выбрать любой другой стиль (из папки [BibTeX-Styles](BibTeX-Styles) или найденный в интернете). В файле biblio.bib аккуратно приведена вся библиография из ГОСТ Р 7.0.11-2011 и примеры всех типов документов на английском, так что вы можете попробовать все интересующие вас стили и увидеть, как каждый из них форматирует библиографию. 
* В стилевых файлов русских ГОСТ-ов многие типы документов (например, *PHDTHESIS* или *TECHREPORT*) сделаны очень плохо. В большинстве случаев лучше их вполне можно заменить на *ARTICLE* или *BOOK*.
* ```bibtex```(```bibtex8```) некорректно работает с преобразованиями юникодных символов, потому сокращения до инициалов или возможности по изменению регистра с utf8 работать не будут. Соответствующим образом надо заполнять ```*.bib``` файл.
* Подборка русских стилевых пакетов BibTeX под UTF-8 размещена в папке [BibTeX-Styles/](./BibTeX-Styles/).
#### ugost2008mod.bst
Доработанный шаблон ```ugost2008.bst```:
- Теперь не ругается на тип ```@Mastersthesis```.
- Теперь есть три функции (вместо одной) для выделения текста: авторы, журнал, том издания, которыми можно управлять. По умолчанию выделения нет.
Пример задания выделения перед вызовом библиографии (авторы - курсив, журнал - жирный, том - подчеркнутый):
```tex
\providecommand*{\BibEmph}[1]{\emph{#1}}
\providecommand*{\BibEmphi}[1]{\textbf{#1}}
\providecommand*{\BibEmphii}[1]{\underline{#1}} 
```
- Ссылка DOI, при наличии у любого типа записей теперь проставлена у первых пунктов после номера в списке литературы, а не  только у названия журнала или книги.

- Если у записи есть DOI, но нет URL или eprint, то в конец записи в списке литературы пишется DOI: ...

- Для того, чтобы убрать DOI из отображения, перед запуском библиографии пишется:
```tex
\makeatletter %http://tex.stackexchange.com/questions/40590/is-there-a-command-to-ignore-the-following-character
\def\?#1{}        % средство удаления последующего знака
\makeatother
\providecommand*{\BibDOI}[1]{\?}   % Пустой DOI, съедающий следующую за собой точку
```
- Как и у базового ```ugost2008.bst``` можно отключить разделительное тире между элементами записи, записав перед вызовов библиографии:
```tex
\providecommand*{\BibDash}{}
```
- Теперь, если авторов больше трёх, то они перемещаются правее заглавия, в область указания ответственности,  и там сокращаются до первого «[и др.]» (согласно распространённой практике применения библиографических ГОСТов). 



## Дополнительная информация
Справка к пакету ```biblatex-gost``` рассказывает [о взаимосвязи ГОСТов на библиографию](http://mirrors.ctan.org/macros/latex/contrib/biblatex-contrib/biblatex-gost/doc/biblatex-gost.pdf).

[Цитирование в диссертации: рекомендации по оформлению](http://www.dissernet.org/instructions/instruction/citation-in-the-thesis-recommendations-on-the-formulation.htm).

## В случае проблем
Многие проблемы связаны с несоответствием выбранного движка данного шаблона и движка настроенного в пользовательской системе для компиляции по умолчанию. Движок настраивается в файлах ```setup.tex``` в строчке кода:
```tex
\setcounter{bibliosel}{1}           % 0 --- встроенная реализация с загрузкой файла через движок bibtex8; 1 --- реализация пакетом biblatex через движок biber
```

В случае проблем компиляции библиографии, попробуйте настроить в среде компиляции запуск bibtex8:
```bat
bibtex8.exe -B -c utf8cyrillic.csf %
```
где ```%``` --- имя файла без расширения, или

```bat
bibtex8.exe -B -c utf8cyrillic.csf dissertation.aux
```

Если выводится в ошибка
```
I found no \citation commands---while reading file dissertation.aux
```
то, например под windows/texlive 2015/texstudio «лечится» изменением в `Параметры`-`Конфигурация TeXStudio`-`Построение` `библиография по умолчанию` на `Biber` (стоит часто `BibTeX` и не работает, если в файлах `setup.tex` настроено `\setcounter{bibliosel}{1}`).

## Черновик draft.tex

Упрощённая версия шаблона, сделанная для уменьшения времени
промежуточной сборки (например, для проверки вёрстки формул),
находится в файле draft.tex (пока только для автореферата) и всегда
использует более функциональный движок библиографии biber.
